@@ -6,7 +6,6 @@ package commands
 import (
 	"bytes"
 	"io/ioutil"
-	"os"
 	"path/filepath"
 	"strings"
 	"testing"
@@ -58,7 +57,6 @@ func TestAnnotateCommand(t *testing.T) {
 		tt := tests[i]
 		t.Run(tt.name, func(t *testing.T) {
 			d := initTestDir(t)
-			defer os.RemoveAll(d)
 
 			a := NewAnnotateRunner("")
 			a.Command.SetArgs(append([]string{d}, tt.args...))
@@ -88,18 +86,14 @@ func TestAnnotateCommand(t *testing.T) {
 }
 
 func initTestDir(t *testing.T) string {
-	d, err := ioutil.TempDir("", "kustomize-annotate-test")
+	t.Helper()
+	d := t.TempDir()
+	err := ioutil.WriteFile(filepath.Join(d, "f1.yaml"), []byte(f1Input), 0600)
 	if !assert.NoError(t, err) {
 		t.FailNow()
 	}
-	err = ioutil.WriteFile(filepath.Join(d, "f1.yaml"), []byte(f1Input), 0600)
-	if !assert.NoError(t, err) {
-		defer os.RemoveAll(d)
-		t.FailNow()
-	}
 	err = ioutil.WriteFile(filepath.Join(d, "f2.yaml"), []byte(f2Input), 0600)
 	if !assert.NoError(t, err) {
-		defer os.RemoveAll(d)
 		t.FailNow()
 	}
 	return d
@@ -585,28 +579,24 @@ added annotations in the package
 			openapi.ResetOpenAPI()
 			defer openapi.ResetOpenAPI()
 			sourceDir := filepath.Join("test", "testdata", test.dataset)
-			baseDir, err := ioutil.TempDir("", "")
-			if !assert.NoError(t, err) {
-				t.FailNow()
-			}
+			baseDir := t.TempDir()
 			copyutil.CopyDir(sourceDir, baseDir)
-			defer os.RemoveAll(baseDir)
 			runner := NewAnnotateRunner("")
 			actual := &bytes.Buffer{}
 			runner.Command.SetOut(actual)
 			runner.Command.SetArgs(append([]string{filepath.Join(baseDir, test.packagePath)}, test.args...))
-			err = runner.Command.Execute()
+			err := runner.Command.Execute()
 			if !assert.NoError(t, err) {
 				t.FailNow()
 			}
 
 			// normalize path format for windows
-			actualNormalized := strings.Replace(
-				strings.Replace(actual.String(), "\\", "/", -1),
-				"//", "/", -1)
+			actualNormalized := strings.ReplaceAll(
+				strings.ReplaceAll(actual.String(), "\\", "/"),
+				"//", "/")
 
-			expected := strings.Replace(test.expected, "${baseDir}", baseDir, -1)
-			expectedNormalized := strings.Replace(expected, "\\", "/", -1)
+			expected := strings.ReplaceAll(test.expected, "${baseDir}", baseDir)
+			expectedNormalized := strings.ReplaceAll(expected, "\\", "/")
 			if !assert.Contains(t, actualNormalized, expectedNormalized) {
 				t.FailNow()
 			}
