@@ -699,14 +699,10 @@ spec:
 			openapi.ResetOpenAPI()
 			defer openapi.ResetOpenAPI()
 
-			baseDir, err := ioutil.TempDir("", "")
-			if !assert.NoError(t, err) {
-				t.FailNow()
-			}
-			defer os.RemoveAll(baseDir)
+			baseDir := t.TempDir()
 
 			f := filepath.Join(baseDir, "Krmfile")
-			err = ioutil.WriteFile(f, []byte(test.inputOpenAPI), 0600)
+			err := ioutil.WriteFile(f, []byte(test.inputOpenAPI), 0600)
 			if !assert.NoError(t, err) {
 				t.FailNow()
 			}
@@ -716,7 +712,10 @@ spec:
 				if !assert.NoError(t, err) {
 					t.FailNow()
 				}
-				defer os.Remove(sch.Name())
+				t.Cleanup(func() {
+					sch.Close()
+					os.Remove(sch.Name())
+				})
 
 				err = ioutil.WriteFile(sch.Name(), []byte(test.schema), 0600)
 				if !assert.NoError(t, err) {
@@ -730,7 +729,7 @@ spec:
 			if !assert.NoError(t, err) {
 				t.FailNow()
 			}
-			defer os.Remove(r.Name())
+			t.Cleanup(func() { r.Close() })
 			err = ioutil.WriteFile(r.Name(), []byte(test.input), 0600)
 			if !assert.NoError(t, err) {
 				t.FailNow()
@@ -753,12 +752,12 @@ spec:
 				t.FailNow()
 			}
 
-			expectedOut := strings.Replace(test.out, "${baseDir}", baseDir, -1)
-			expectedNormalized := strings.Replace(expectedOut, "\\", "/", -1)
+			expectedOut := strings.ReplaceAll(test.out, "${baseDir}", baseDir)
+			expectedNormalized := strings.ReplaceAll(expectedOut, "\\", "/")
 			// normalize path format for windows
-			actualNormalized := strings.Replace(
-				strings.Replace(out.String(), "\\", "/", -1),
-				"//", "/", -1)
+			actualNormalized := strings.ReplaceAll(
+				strings.ReplaceAll(out.String(), "\\", "/"),
+				"//", "/")
 
 			if !assert.Contains(t, actualNormalized, expectedNormalized) {
 				t.FailNow()
@@ -847,28 +846,24 @@ setter with name "namespace" already exists, if you want to modify it, please de
 			openapi.ResetOpenAPI()
 			defer openapi.ResetOpenAPI()
 			sourceDir := filepath.Join("test", "testdata", test.dataset)
-			baseDir, err := ioutil.TempDir("", "")
-			if !assert.NoError(t, err) {
-				t.FailNow()
-			}
+			baseDir := t.TempDir()
 			copyutil.CopyDir(sourceDir, baseDir)
-			defer os.RemoveAll(baseDir)
 			runner := commands.NewCreateSetterRunner("")
 			actual := &bytes.Buffer{}
 			runner.Command.SetOut(actual)
 			runner.Command.SetArgs(append([]string{filepath.Join(baseDir, test.packagePath)}, test.args...))
-			err = runner.Command.Execute()
+			err := runner.Command.Execute()
 			if !assert.NoError(t, err) {
 				t.FailNow()
 			}
 
 			// normalize path format for windows
-			actualNormalized := strings.Replace(
-				strings.Replace(actual.String(), "\\", "/", -1),
-				"//", "/", -1)
+			actualNormalized := strings.ReplaceAll(
+				strings.ReplaceAll(actual.String(), "\\", "/"),
+				"//", "/")
 
-			expected := strings.Replace(test.expected, "${baseDir}", baseDir, -1)
-			expectedNormalized := strings.Replace(expected, "\\", "/", -1)
+			expected := strings.ReplaceAll(test.expected, "${baseDir}", baseDir)
+			expectedNormalized := strings.ReplaceAll(expected, "\\", "/")
 			if !assert.Contains(t, actualNormalized, expectedNormalized) {
 				t.FailNow()
 			}
